==> charity-base-search-3.2.1.tgz: package/es/index.js <==
import React, { useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import debounce from 'lodash.debounce';
import FilterSuggest, { HelperText, Input, TextField } from 'filter-suggest';
import svgSearch from './search.svg';

var DEBOUNCE_TIME = 100;
var applyDebounced = debounce(function (f, x) {
  return f(x);
}, DEBOUNCE_TIME);

var URL = 'https://charitybase.uk/api/graphql';
var QUERY = '\n  query CBS_SEARCH_FILTERS(\n    $search: String!\n    $filterType: [String]\n  ) {\n    CHC {\n      getFilters(\n        search: $search\n        filterType: $filterType\n      ) {\n        id\n        value\n        label\n        filterType\n        score\n      }\n    }\n  }\n';

var getData = function getData(apiKey, variables) {
  return fetch(URL + '?query=' + QUERY + '&variables=' + JSON.stringify(variables), {
    headers: {
      Authorization: 'Apikey ' + apiKey
    }
  }).then(function (x) {
    return x.json();
  });
};

var getSearchItem = function getSearchItem(inputValue) {
  return {
    id: 'search-' + inputValue,
    value: inputValue,
    label: inputValue,
    filterType: 'search'
  };
};

var errorMessage = function errorMessage(_ref) {
  var error = _ref.error,
      empty = _ref.empty,
      loading = _ref.loading,
      searchTerm = _ref.searchTerm;

  if (error) {
    return 'Oops something went wrong, please try again';
  }
  if (empty && searchTerm.length > 1 && !loading) {
    return 'Sorry we can\'t find anything matching \'' + searchTerm + '\'';
  }
  return null;
};

var CharityBaseSearch = function CharityBaseSearch(_ref2) {
  var apiKey = _ref2.apiKey,
      className = _ref2.className,
      filterTypes = _ref2.filterTypes,
      hideAcknowledgement = _ref2.hideAcknowledgement,
      label = _ref2.label,
      mapItem = _ref2.mapItem,
      menuClassName = _ref2.menuClassName,
      onBlur = _ref2.onBlur,
      onFocus = _ref2.onFocus,
      _onSelect = _ref2.onSelect,
      outlined = _ref2.outlined,
      textFieldClassName = _ref2.textFieldClassName;

  var _useState = useState(''),
      inputValue = _useState[0],
      setInputValue = _useState[1];

  var _useState2 = useState(''),
      debouncedInputValue = _useState2[0],
      setDebouncedInputValue = _useState2[1];

  var _useState3 = useState(null),
      data = _useState3[0],
      setData = _useState3[1];

  var _useState4 = useState(null),
      error = _useState4[0],
      setError = _useState4[1];

  var _useState5 = useState(0),
      fetchCount = _useState5[0],
      setFetchCount = _useState5[1];

  var onInputValueChange = function onInputValueChange(x) {
    var value = x || '';
    setInputValue(value);
    applyDebounced(setDebouncedInputValue, value);
  };

  useEffect(function () {
    var variables = { search: debouncedInputValue, filterType: filterTypes };
    setFetchCount(function (x) {
      return x + 1;
    });
    getData(apiKey, variables)
    // todo: check fetch count before setting data (don't want to overwrite with old, slow search)
    .then(function (_ref3) {
      var data = _ref3.data,
          errors = _ref3.errors;

      if (errors) {
        // setData(null)
        return setError(errors[0].message); // graphql error
      }
      setError(null);
      setData(data);
    }).catch(function (error) {
      // setData(null)
      setError(error.message); // probably network error
    }).then(function () {
      return setFetchCount(function (x) {
        return x - 1;
      });
    });
  }, [apiKey, debouncedInputValue, filterTypes]);

  var syncItems = [getSearchItem(inputValue)].reduce(function (agg, x) {
    return filterTypes && filterTypes.indexOf(x.filterType) === -1 ? agg : [].concat(agg, [x]);
  }, []);
  var filterItems = inputValue && data && data.CHC ? [].concat(syncItems, data.CHC.getFilters) : [];
  return React.createElement(
    'div',
    null,
    hideAcknowledgement ? null : React.createElement(
      'a',
      {
        className: 'cbs-acknowledgement',
        href: 'https://charitybase.uk',
        target: '_blank',
        rel: 'noopener noreferrer'
      },
      'Powered by CharityBase'
    ),
    React.createElement(FilterSuggest, {
      className: className,
      errorMessage: errorMessage({
        error: error,
        empty: filterItems.length === 0,
        loading: fetchCount > 0,
        searchTerm: debouncedInputValue
      }),
      inputValue: inputValue,
      items: filterItems.map(mapItem),
      label: label,
      leadingIcon: React.createElement('img', { width: 24, height: 24, src: svgSearch }),
      loading: fetchCount > 0,
      menuClassName: menuClassName,
      onBlur: onBlur,
      onFocus: onFocus,
      onInputValueChange: onInputValueChange,
      onSelect: function onSelect(item) {
        onInputValueChange('');
        _onSelect(item);
      },
      outlined: outlined,
      textFieldClassName: textFieldClassName
    })
  );
};
CharityBaseSearch.propTypes = process.env.NODE_ENV !== "production" ? {
  apiKey: PropTypes.string.isRequired,
  className: PropTypes.string,
  filterTypes: PropTypes.array,
  hideAcknowledgement: PropTypes.bool,
  label: PropTypes.string,
  mapItem: PropTypes.func,
  menuClassName: PropTypes.string,
  onBlur: PropTypes.func,
  onFocus: PropTypes.func,
  onSelect: PropTypes.func.isRequired,
  outlined: PropTypes.bool,
  textFieldClassName: PropTypes.string
} : {};
CharityBaseSearch.defaultProps = {
  label: 'Search charities',
  mapItem: function mapItem(_ref4) {
    var id = _ref4.id,
        filterType = _ref4.filterType,
        value = _ref4.value,
        label = _ref4.label;
    return { // __typename ?
      id: id,
      filterType: filterType,
      value: value,
      label: label,
      icon: null,
      primary: label,
      secondary: 'Filter by ' + filterType
    };
  }
};

export default CharityBaseSearch;

export { HelperText, Input, TextField };

==> charity-base-search-3.3.2.tgz: package/es/index.js <==
import React, { useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import debounce from 'lodash.debounce';
import FilterSuggest, { HelperText, Input, TextField } from 'filter-suggest';
import svgSearch from './search.svg';

var DEBOUNCE_TIME = 100;
var applyDebounced = debounce(function (f, x) {
  return f(x);
}, DEBOUNCE_TIME);

var URL = 'https://charitybase.uk/api/graphql';
var QUERY = '\n  query CBS_SEARCH_FILTERS(\n    $search: String!\n    $filterType: [String]\n  ) {\n    CHC {\n      getFilters(\n        search: $search\n        filterType: $filterType\n      ) {\n        id\n        value\n        label\n        filterType\n        score\n      }\n    }\n  }\n';

var getData = function getData(apiKey, variables) {
  return fetch(URL + '?query=' + QUERY + '&variables=' + JSON.stringify(variables), {
    headers: {
      Authorization: 'Apikey ' + apiKey
    }
  }).then(function (x) {
    return x.json();
  });
};

var getSearchItem = function getSearchItem(inputValue) {
  return {
    id: 'search-' + inputValue,
    value: inputValue,
    label: inputValue,
    filterType: 'search'
  };
};

var errorMessage = function errorMessage(_ref) {
  var error = _ref.error,
      empty = _ref.empty,
      loading = _ref.loading,
      searchTerm = _ref.searchTerm;

  if (error) {
    return 'Oops something went wrong, please try again';
  }
  if (empty && searchTerm.length > 1 && !loading) {
    return 'Sorry we can\'t find anything matching \'' + searchTerm + '\'';
  }
  return null;
};

var CharityBaseSearch = function CharityBaseSearch(_ref2) {
  var apiKey = _ref2.apiKey,
      className = _ref2.className,
      filterTypes = _ref2.filterTypes,
      hideAcknowledgement = _ref2.hideAcknowledgement,
      label = _ref2.label,
      mapItem = _ref2.mapItem,
      menuClassName = _ref2.menuClassName,
      onBlur = _ref2.onBlur,
      onFocus = _ref2.onFocus,
      _onSelect = _ref2.onSelect,
      outlined = _ref2.outlined,
      style = _ref2.style,
      textFieldClassName = _ref2.textFieldClassName;

  var _useState = useState(''),
      inputValue = _useState[0],
      setInputValue = _useState[1];

  var _useState2 = useState(''),
      debouncedInputValue = _useState2[0],
      setDebouncedInputValue = _useState2[1];

  var _useState3 = useState(null),
      data = _useState3[0],
      setData = _useState3[1];

  var _useState4 = useState(null),
      error = _useState4[0],
      setError = _useState4[1];

  var _useState5 = useState(0),
      fetchCount = _useState5[0],
      setFetchCount = _useState5[1];

  var onInputValueChange = function onInputValueChange(x) {
    var value = x || '';
    setInputValue(value);
    applyDebounced(setDebouncedInputValue, value);
  };

  useEffect(function () {
    if (debouncedInputValue) {
      var variables = { search: debouncedInputValue, filterType: filterTypes };
      setFetchCount(function (x) {
        return x + 1;
      });
      getData(apiKey, variables)
      // todo: check fetch count before setting data (don't want to overwrite with old, slow search)
      .then(function (_ref3) {
        var data = _ref3.data,
            errors = _ref3.errors;

        if (errors) {
          // setData(null)
          return setError(errors[0].message); // graphql error
        }
        setError(null);
        setData(data);
      }).catch(function (error) {
        // setData(null)
        setError(error && error.message || 'Unknown error'); // probably network error
      }).then(function () {
        setFetchCount(function (x) {
          return x - 1;
        });
      });
    } else {
      setError(null);
      setData(null);
    }
  }, [apiKey, debouncedInputValue, JSON.stringify(filterTypes)]);

  var syncItems = [getSearchItem(inputValue)].reduce(function (agg, x) {
    return filterTypes && filterTypes.indexOf(x.filterType) === -1 ? agg : [].concat(agg, [x]);
  }, []);
  var filterItems = inputValue && data && data.CHC ? [].concat(syncItems, data.CHC.getFilters) : [];
  return React.createElement(
    'div',
    { className: className, style: style },
    hideAcknowledgement ? null : React.createElement(
      'a',
      {
        className: 'cbs-acknowledgement',
        href: 'https://charitybase.uk',
        target: '_blank',
        rel: 'noopener noreferrer'
      },
      'Powered by CharityBase'
    ),
    React.createElement(FilterSuggest, {
      errorMessage: errorMessage({
        error: error,
        empty: filterItems.length === 0,
        loading: fetchCount > 0,
        searchTerm: debouncedInputValue
      }),
      inputValue: inputValue,
      items: filterItems.map(mapItem),
      label: label,
      leadingIcon: React.createElement('img', { width: 24, height: 24, src: svgSearch }),
      loading: fetchCount > 0,
      menuClassName: menuClassName,
      onBlur: onBlur,
      onFocus: onFocus,
      onInputValueChange: onInputValueChange,
      onSelect: function onSelect(item) {
        onInputValueChange('');
        _onSelect(item);
      },
      outlined: outlined,
      textFieldClassName: textFieldClassName
    })
  );
};
CharityBaseSearch.propTypes = process.env.NODE_ENV !== "production" ? {
  apiKey: PropTypes.string.isRequired,
  className: PropTypes.string,
  filterTypes: PropTypes.array,
  hideAcknowledgement: PropTypes.bool,
  label: PropTypes.string,
  mapItem: PropTypes.func,
  menuClassName: PropTypes.string,
  onBlur: PropTypes.func,
  onFocus: PropTypes.func,
  onSelect: PropTypes.func.isRequired,
  outlined: PropTypes.bool,
  style: PropTypes.object,
  textFieldClassName: PropTypes.string
} : {};
CharityBaseSearch.defaultProps = {
  label: 'Search charities',
  mapItem: function mapItem(_ref4) {
    var id = _ref4.id,
        filterType = _ref4.filterType,
        value = _ref4.value,
        label = _ref4.label;
    return { // __typename ?
      id: id,
      filterType: filterType,
      value: value,
      label: label,
      icon: null,
      primary: label,
      secondary: 'Filter by ' + filterType
    };
  }
};

export default CharityBaseSearch;

export { HelperText, Input, TextField };
